@@ -218,7 +218,7 @@ class K3SController:
 
 repo_info = \
 {
-    "K3SController":{
+    "K3SRepository":{
         "add_node_label":{
             "args":[["node_infos", True, "NodeInfo", None, True], ["key", False], ["value", False]],
             "ret":["command_result", True, None, None, True, True]
